# -*- coding: utf-8 -*-

"""
    Tortilla
    ~~~~~~~~

    A tiny Python library for creating wrappers around web APIs.

    :copyright: (c) 2014 by Hidde Bultsma.
    :license: MIT, see LICENSE for more details.
"""

from __future__ import unicode_literals

from .api import wrap
from .wrappers import Wrap
